Script: *check-pnp-devices.ps1*
========================

This PowerShell script checks all Plug'n'PLay devices connected to the local computer.

Parameters
----------
```powershell
PS> ./check-pnp-devices.ps1 [<CommonParameters>]

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./check-pnp-devices.ps1



FriendlyName                 Status  InstanceId
------------                 ------  ----------
Microsoft-Controller         OK      ROOT\SPACEPORT\0000
...

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Checks PnP devices
.DESCRIPTION
	This PowerShell script checks all Plug'n'PLay devices connected to the local computer.
.EXAMPLE
	PS> ./check-pnp-devices.ps1

	FriendlyName                 Status  InstanceId
	------------                 ------  ----------
	Microsoft-Controller         OK      ROOT\SPACEPORT\0000
	...
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

try {
	Get-PnpDevice | Where-Object {$_.Status -like "Error"} | Format-Table -property FriendlyName,Status,InstanceId
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(generated by convert-ps2md.ps1 using the comment-based help of check-pnp-devices.ps1 as of 08/15/2024 09:50:46)*
