Script: *list-usb-devices.ps1*
========================

This PowerShell script lists all USB devices connected to the local computer.

Parameters
----------
```powershell
PS> ./list-usb-devices.ps1 [<CommonParameters>]

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./list-usb-devices.ps1



FriendlyName                 Status  InstanceId
------------                 ------  ----------
USB-Root-Hub (USB 3.0)       OK      USB\ROOT_HUB30\4&2060378&0&0
...

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Lists USB devices
.DESCRIPTION
	This PowerShell script lists all USB devices connected to the local computer.
.EXAMPLE
	PS> ./list-usb-devices.ps1

	FriendlyName                 Status  InstanceId
	------------                 ------  ----------
	USB-Root-Hub (USB 3.0)       OK      USB\ROOT_HUB30\4&2060378&0&0
	...
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

try {
	Get-PnpDevice | Where-Object {$_.Class -eq "USB"} | Sort-Object -property FriendlyName | Format-Table -property FriendlyName,Status,InstanceId
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(generated by convert-ps2md.ps1 using the comment-based help of list-usb-devices.ps1 as of 08/15/2024 09:50:50)*
