Script: *watch-news.ps1*
========================

This PowerShell script lists the latest headlines by using a RSS (Really Simple Syndication) feed.

Parameters
----------
```powershell
PS> ./watch-news.ps1 [[-RSS_URL] <String>] [[-lines] <Int32>] [[-timeInterval] <Int32>] [<CommonParameters>]

-RSS_URL <String>
    Specifies the URL to the RSS feed (Yahoo World News by default)
    
    Required?                    false
    Position?                    1
    Default value                https://news.yahoo.com/rss/world
    Accept pipeline input?       false
    Accept wildcard characters?  false

-lines <Int32>
    Specifies the initial number of headlines
    
    Required?                    false
    Position?                    2
    Default value                10
    Accept pipeline input?       false
    Accept wildcard characters?  false

-timeInterval <Int32>
    Specifies the time interval in seconds between the Web requests
    
    Required?                    false
    Position?                    3
    Default value                30
    Accept pipeline input?       false
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./watch-news.ps1
❇️ Niger coup: Ecowas deadline sparks anxiety in northern Nigeria ❇️

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Watch the latest headlines
.DESCRIPTION
	This PowerShell script lists the latest headlines by using a RSS (Really Simple Syndication) feed.
.PARAMETER RSS_URL
	Specifies the URL to the RSS feed (Yahoo World News by default)
.PARAMETER lines
	Specifies the initial number of headlines
.PARAMETER timeInterval
	Specifies the time interval in seconds between the Web requests
.EXAMPLE
	PS> ./watch-news.ps1
	❇️ Niger coup: Ecowas deadline sparks anxiety in northern Nigeria ❇️
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$RSS_URL = "https://news.yahoo.com/rss/world", [int]$lines = 10, [int]$timeInterval = 30) # in seconds

function PrintLatestHeadlines([string]$previous, [int]$maxLines) {
	[xml]$content = (Invoke-WebRequest -URI $RSS_URL -useBasicParsing).Content
	[string]$latest = ""

	foreach ($item in $content.rss.channel.item) {
		$itemTitle = "$($item.title)"
		if ($latest -eq "") { $latest = $itemTitle }
		if ($itemTitle -eq $previous) { break }

		& "$PSScriptRoot/write-animated.ps1" "❇️ $itemTitle ❇️"
		$maxLines--
		if ($maxLines -eq 0) { break }
	}
	return $latest
}

try {
	$latest = ""
	while ($true) {
		$latest = PrintLatestHeadlines $latest $lines
		Start-Sleep -seconds $timeInterval
	}
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(generated by convert-ps2md.ps1 using the comment-based help of watch-news.ps1 as of 08/15/2024 09:50:55)*
